@@ -1,4 +1,4 @@
-﻿package Map::Tube::Node;
+package Map::Tube::Node;
 
 use strict; use warnings;
 
@@ -12,11 +12,11 @@ Map::Tube::Node - Defines the node for Map::Tube
 
 =head1 VERSION
 
-Version 1.0
+Version 1.1
 
 =cut
 
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 
 Readonly my $BAKERLOO => {
     'Harrow & Wealdstone' => 'B1',
